@@ -12,6 +12,7 @@ from .basic_components import MarkdownTextObject
 from .basic_components import PlainTextObject
 from .basic_components import TextObject
 from .block_elements import BlockElement
+from .block_elements import ImageElement
 from .block_elements import InputInteractiveElement
 from .block_elements import InteractiveElement
 
@@ -93,9 +94,7 @@ class Block(JsonObject):
                 return None
 
     @classmethod
-    def parse_all(
-        cls, blocks: Optional[Sequence[Union[dict, "Block"]]]
-    ) -> List["Block"]:
+    def parse_all(cls, blocks: Optional[Sequence[Union[dict, "Block"]]]) -> List["Block"]:
         return [cls.parse(b) for b in blocks or []]
 
 
@@ -117,13 +116,29 @@ class SectionBlock(Block):
         self,
         *,
         block_id: Optional[str] = None,
-        text: Union[str, dict, TextObject] = None,
-        fields: Sequence[Union[str, dict, TextObject]] = None,
+        text: Optional[Union[str, dict, TextObject]] = None,
+        fields: Optional[Sequence[Union[str, dict, TextObject]]] = None,
         accessory: Optional[Union[dict, BlockElement]] = None,
         **others: dict,
     ):
         """A section is one of the most flexible blocks available.
         https://api.slack.com/reference/block-kit/blocks#section
+
+        Args:
+            block_id (required): A string acting as a unique identifier for a block.
+                If not specified, one will be generated.
+                You can use this block_id when you receive an interaction payload to identify the source of the action.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message and each iteration of a message.
+                If a message is updated, use a new block_id.
+            text (preferred): The text for the block, in the form of a text object.
+                Maximum length for the text in this field is 3000 characters.
+                This field is not required if a valid array of fields objects is provided instead.
+            fields (required if no text is provided): Required if no text is provided.
+                An array of text objects. Any text objects included with fields will be rendered
+                in a compact format that allows for 2 columns of side-by-side text.
+                Maximum number of items is 10. Maximum length for the text in each item is 2000 characters.
+            accessory: One of the available element objects.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
@@ -171,6 +186,13 @@ class DividerBlock(Block):
     ):
         """A content divider, like an <hr>, to split up different blocks inside of a message.
         https://api.slack.com/reference/block-kit/blocks#divider
+
+        Args:
+            block_id: A string acting as a unique identifier for a block. If not specified, one will be generated.
+                You can use this block_id when you receive an interaction payload to identify the source of the action.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message and each iteration of a message.
+                If a message is updated, use a new block_id.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
@@ -198,6 +220,18 @@ class ImageBlock(Block):
     ):
         """A simple image block, designed to make those cat photos really pop.
         https://api.slack.com/reference/block-kit/blocks#image
+
+        Args:
+            image_url (required): The URL of the image to be displayed.
+                Maximum length for this field is 3000 characters.
+            alt_text (required): A plain-text summary of the image. This should not contain any markup.
+                Maximum length for this field is 2000 characters.
+            title: An optional title for the image in the form of a text object that can only be of type: plain_text.
+                Maximum length for the text in this field is 2000 characters.
+            block_id: A string acting as a unique identifier for a block. If not specified, one will be generated.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message and each iteration of a message.
+                If a message is updated, use a new block_id.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
@@ -206,9 +240,7 @@ class ImageBlock(Block):
         self.alt_text = alt_text
         self.title = TextObject.parse(title)
 
-    @JsonValidator(
-        f"image_url attribute cannot exceed {image_url_max_length} characters"
-    )
+    @JsonValidator(f"image_url attribute cannot exceed {image_url_max_length} characters")
     def _validate_image_url_length(self):
         return len(self.image_url) <= self.image_url_max_length
 
@@ -218,11 +250,7 @@ class ImageBlock(Block):
 
     @JsonValidator(f"title attribute cannot exceed {title_max_length} characters")
     def _validate_title_length(self):
-        return (
-            self.title is None
-            or self.title.text is None
-            or len(self.title.text) <= self.title_max_length
-        )
+        return self.title is None or self.title.text is None or len(self.title.text) <= self.title_max_length
 
 
 class ActionsBlock(Block):
@@ -242,6 +270,16 @@ class ActionsBlock(Block):
     ):
         """A block that is used to hold interactive elements.
         https://api.slack.com/reference/block-kit/blocks#actions
+
+        Args:
+            elements (required): An array of interactive element objects - buttons, select menus, overflow menus,
+                or date pickers. There is a maximum of 5 elements in each action block.
+            block_id: A string acting as a unique identifier for a block.
+                If not specified, a block_id will be generated.
+                You can use this block_id when you receive an interaction payload to identify the source of the action.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message and each iteration of a message.
+                If a message is updated, use a new block_id.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
@@ -264,12 +302,19 @@ class ContextBlock(Block):
     def __init__(
         self,
         *,
-        elements: Sequence[Union[dict, ImageBlock, TextObject]],
+        elements: Sequence[Union[dict, ImageElement, TextObject]],
         block_id: Optional[str] = None,
         **others: dict,
     ):
         """Displays message context, which can include both images and text.
         https://api.slack.com/reference/block-kit/blocks#context
+
+        Args:
+            elements (required): An array of image elements and text objects. Maximum number of items is 10.
+            block_id: A string acting as a unique identifier for a block. If not specified, one will be generated.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message and each iteration of a message.
+                If a message is updated, use a new block_id.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
@@ -288,9 +333,7 @@ class InputBlock(Block):
 
     @property
     def attributes(self) -> Set[str]:
-        return super().attributes.union(
-            {"label", "hint", "element", "optional", "dispatch_action"}
-        )
+        return super().attributes.union({"label", "hint", "element", "optional", "dispatch_action"})
 
     def __init__(
         self,
@@ -306,6 +349,23 @@ class InputBlock(Block):
         """A block that collects information from users - it can hold a plain-text input element,
         a select menu element, a multi-select menu element, or a datepicker.
         https://api.slack.com/reference/block-kit/blocks#input
+
+        Args:
+            label (required): A label that appears above an input element in the form of a text object
+                that must have type of plain_text. Maximum length for the text in this field is 2000 characters.
+            element (required): An plain-text input element, a checkbox element, a radio button element,
+                a select menu element, a multi-select menu element, or a datepicker.
+            block_id: A string acting as a unique identifier for a block. If not specified, one will be generated.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message or view and each iteration of a message or view.
+                If a message or view is updated, use a new block_id.
+            hint: An optional hint that appears below an input element in a lighter grey.
+                It must be a text object with a type of plain_text.
+                Maximum length for the text in this field is 2000 characters.
+            dispatch_action: A boolean that indicates whether or not the use of elements in this block
+                should dispatch a block_actions payload. Defaults to false.
+            optional: A boolean that indicates whether the input element may be empty when a user submits the modal.
+                Defaults to false.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
@@ -318,19 +378,11 @@ class InputBlock(Block):
 
     @JsonValidator(f"label attribute cannot exceed {label_max_length} characters")
     def _validate_label_length(self):
-        return (
-            self.label is None
-            or self.label.text is None
-            or len(self.label.text) <= self.label_max_length
-        )
+        return self.label is None or self.label.text is None or len(self.label.text) <= self.label_max_length
 
     @JsonValidator(f"hint attribute cannot exceed {hint_max_length} characters")
     def _validate_hint_length(self):
-        return (
-            self.hint is None
-            or self.hint.text is None
-            or len(self.hint.text) <= self.label_max_length
-        )
+        return self.hint is None or self.hint.text is None or len(self.hint.text) <= self.label_max_length
 
     @JsonValidator(
         (
@@ -339,9 +391,7 @@ class InputBlock(Block):
         )
     )
     def _validate_element_type(self):
-        return self.element is None or isinstance(
-            self.element, (str, InputInteractiveElement)
-        )
+        return self.element is None or isinstance(self.element, (str, InputInteractiveElement))
 
 
 class FileBlock(Block):
@@ -361,6 +411,14 @@ class FileBlock(Block):
     ):
         """Displays a remote file.
         https://api.slack.com/reference/block-kit/blocks#file
+
+        Args:
+            external_id (required): The external unique ID for this file.
+            source (required): At the moment, source will always be remote for a remote file.
+            block_id: A string acting as a unique identifier for a block. If not specified, one will be generated.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message and each iteration of a message.
+                If a message is updated, use a new block_id.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
@@ -408,11 +466,19 @@ class HeaderBlock(Block):
         self,
         *,
         block_id: Optional[str] = None,
-        text: Union[str, dict, TextObject] = None,
+        text: Optional[Union[str, dict, TextObject]] = None,
         **others: dict,
     ):
         """A header is a plain-text block that displays in a larger, bold font.
         https://api.slack.com/reference/block-kit/blocks#header
+
+        Args:
+            block_id: A string acting as a unique identifier for a block. If not specified, one will be generated.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message and each iteration of a message.
+                If a message is updated, use a new block_id.
+            text (required): The text for the block, in the form of a plain_text text object.
+                Maximum length for the text in this field is 150 characters.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
